[![CircleCI branch](https://img.shields.io/circleci/project/github/mkeshav/data-genie/master.svg)](https://circleci.com/gh/mkeshav/data-genie/tree/master)
[![PyPI version](https://badge.fury.io/py/data-genie.svg)](https://badge.fury.io/py/data-genie)
[![Documentation Status](https://readthedocs.org/projects/data-genie/badge/?version=latest)](https://data-genie.readthedocs.io/en/latest/?badge=latest)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=mkeshav_data-genie&metric=alert_status)](https://sonarcloud.io/dashboard?id=mkeshav_data-genie)

# Data Genie
Genie that can satisfy your data wish.

### QuickStart

- `python3 -m pip install data-genie`
- Detailed [Documentation](https://data-genie.readthedocs.io)

### Supported Formats

- Fixed Width
- Delimited (CSV)
- JSON

### Data quality

`dqc` module allows to write data quality checks on pandas data frame.
